@@ -6,6 +6,6 @@ RoboMentor_Client: Python library and framework for RoboMentor_Client.
 :license: MIT, see LICENSE for more details.
 """
 
-__version__ = "1.1.0"
+__version__ = "1.2.9"
 __apiUrl__ = "https://api.robomentor.cn"
-__messageService__ = "47.111.96.253"
+__messageUrl__ = "47.111.96.253"
