@@ -7,3 +7,5 @@ RoboMentor_Client: Python library and framework for RoboMentor_Client.
 """
 
 from .message import Message
+from .service import Service
+from .system import System
