@@ -8,12 +8,11 @@ RoboMentor_Client: Python library and framework for RoboMentor_Client.
 
 import logging
 
-
 class Log:
 
     logging.basicConfig(
         level=logging.DEBUG,
-        format="%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s"
+        format="[%(levelname)s][%(asctime)s][%(filename)s(line:%(lineno)d)]: %(message)s"
     )
 
     @staticmethod
@@ -22,12 +21,12 @@ class Log:
 
     @staticmethod
     def info(content):
-        logging.debug(content)
+        logging.info(content)
 
     @staticmethod
     def warning(content):
-        logging.debug(content)
+        logging.warning(content)
 
     @staticmethod
     def error(content):
-        logging.debug(content)
+        logging.error(content)
